# Generated by roxygen2: do not edit by hand

S3method(plot,convhulln)
S3method(plot,delaunayn)
S3method(plot,intersectn)
S3method(to.mesh3d,convhulln)
export("entry.value<-")
export(Unique)
export(bary2cart)
export(cart2bary)
export(cart2pol)
export(cart2sph)
export(convhulln)
export(delaunayn)
export(distmesh2d)
export(distmeshnd)
export(dot)
export(entry.value)
export(extprod3d)
export(feasible.point)
export(halfspacen)
export(inhulln)
export(intersectn)
export(matmax)
export(matmin)
export(matorder)
export(matsort)
export(mesh.dcircle)
export(mesh.diff)
export(mesh.drectangle)
export(mesh.dsphere)
export(mesh.hunif)
export(mesh.intersect)
export(mesh.union)
export(pol2cart)
export(polyarea)
export(rbox)
export(sph2cart)
export(surf.tri)
export(tetramesh)
export(to.mesh3d)
export(trimesh)
export(tsearch)
export(tsearchn)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,box)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,plot.window)
importFrom(graphics,segments)
importFrom(magic,ashift)
importFrom(magic,shift)
importFrom(utils,packageDescription)
useDynLib(geometry)
