# Ellipse
A small demo library for calculating the area of an ellipse

### Installation
```
pip install geometry-543
```

### Get started
How to create an ellipse and calculate the area

```Python
from geometry_543 import Ellipse

# Instantiate an Ellipse object
e = Ellipse(10,13)

# Call the method for calculating the area
result = e.calc_area()
```